@@ -17,7 +17,7 @@ void ImportLibraryDialog::setupUI()
     nameLabel = new QLabel(tr("Library Name : "));
     nameEdit = new QLineEdit;
     nameLabel->setBuddy(nameEdit);
-    connect(nameEdit, SIGNAL(textChanged(QString)), this, SLOT(nameEntered()));
+    connect(nameEdit, &QLineEdit::textChanged, this, &ImportLibraryDialog::nameEntered);
 
     textLabel = new QLabel(tr("Package location : "));
     path = new QLineEdit;
@@ -29,17 +29,17 @@ void ImportLibraryDialog::setupUI()
 
     accept = new QPushButton(tr("Unpack"));
     accept->setDisabled(true);
-    connect(accept, SIGNAL(clicked()), this, SLOT(add()));
+    connect(accept, &QAbstractButton::clicked, this, &ImportLibraryDialog::add);
 
     cancel = new QPushButton(tr("Cancel"));
-    connect(cancel, SIGNAL(clicked()), this, SLOT(close()));
-    //connect(cancel,SIGNAL(clicked()),this,SIGNAL(rejected()));
+    connect(cancel, &QAbstractButton::clicked, this, &ImportLibraryDialog::close);
+    // connect(cancel,SIGNAL(clicked()),this,SIGNAL(rejected()));
 
     find = new QPushButton(QIcon(":/images/find_folder.png"), "");
-    connect(find, SIGNAL(clicked()), this, SLOT(findPath()));
+    connect(find, &QAbstractButton::clicked, this, &ImportLibraryDialog::findPath);
 
     findDest = new QPushButton(QIcon(":/images/find_folder.png"), "");
-    connect(findDest, SIGNAL(clicked()), this, SLOT(findDestination()));
+    connect(findDest, &QAbstractButton::clicked, this, &ImportLibraryDialog::findDestination);
 
     auto content = new QGridLayout;
 
@@ -49,12 +49,12 @@ void ImportLibraryDialog::setupUI()
     content->addWidget(textLabel, 1, 0);
     content->addWidget(path, 1, 1);
     content->addWidget(find, 1, 2);
-    content->setColumnStretch(2, 0); //TODO
+    content->setColumnStretch(2, 0); // TODO
 
     content->addWidget(destLabel, 2, 0);
     content->addWidget(destPath, 2, 1);
     content->addWidget(findDest, 2, 2);
-    //destLayout->setStretchFactor(findDest,0); //TODO
+    // destLayout->setStretchFactor(findDest,0); //TODO
 
     auto bottomLayout = new QHBoxLayout;
     bottomLayout->addStretch();
@@ -69,7 +69,7 @@ void ImportLibraryDialog::setupUI()
 
     auto mainLayout = new QVBoxLayout;
     mainLayout->addLayout(content);
-    //mainLayout->addWidget(progress = new QLabel());
+    // mainLayout->addWidget(progress = new QLabel());
     mainLayout->addStretch();
     mainLayout->addWidget(progressBar);
     mainLayout->addLayout(bottomLayout);
